# //Pulling the weather data from two sources: Weather Underground, and weather.com, a string is formed with the requested data points.
# //wunderground is being html scraped for the condition shown on the site.
# //weather.com runs the API for Wunderground. It is pulling the time, temp, and wind conditions from the at-home wx station.
#
# //Create a registry value that should accept the silly cookie warning from wunderground.com... it gets deleted at the end of the script
reg add "HKCU\SOFTWARE\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3" /t REG_DWORD /v 1A10 /f /d 0
#
# //SCRAPE THE WUNDERGROUND PAGE FOR THE CURRENT CONDITIONS
$UrlWUCond = "https://www.wunderground.com/weather/us/*Your State*/*Your City*/*Your PW Station ID*"
$searchClass = "condition-icon small-6 medium-12 columns"
[Net.ServicePointManager]::SecurityProtocol = [Net.SecurityProtocolType]::Tls12 <# using TLS 1.2 is vitally important #>
$req = Invoke-Webrequest -URI $UrlWUCond
$Condition = $req.ParsedHtml.getElementsByClassName($searchClass)[0].innertext;
#
# //POLL THE WEATHER.COM API TO GET THE CURRENT OBSERVATIONS
$UrlWU = "https://api.weather.com/v2/pws/observations/current?stationId=*your PW Station ID*&format=json&units=e&apiKey=*your WU API Key*"
$CurrentWeather = Invoke-RestMethod "$UrlWU"
$CurrentWeather | ConvertTo-Json -depth 100
#
# //CONVERT THE WIND AND COMPASS DIRECTION FROM THE WX STATION TO BE A UNICODE ARROW AND CARDINAL DIRECTION
# (i.e., wind out of the East will show an arrow pointing West, and the Cardinal direction):
#
if ($CurrentWeather.observations.winddir -gt 22.5 -and $CurrentWeather.observations.winddir -lt 67.5) {$arrow = $([char]0x2199)}
elseif ($CurrentWeather.observations.winddir -gt 67.5 -and $CurrentWeather.observations.winddir -lt 112.5) {$arrow = $([char]0x2190)}
elseif ($CurrentWeather.observations.winddir -gt 112.5 -and $CurrentWeather.observations.winddir -lt 157.5) {$arrow = $([char]0x2196)}
elseif ($CurrentWeather.observations.winddir -gt 157.5 -and $CurrentWeather.observations.winddir -lt 202.5) {$arrow = $([char]0x2191)}
elseif ($CurrentWeather.observations.winddir -gt 202.5 -and $CurrentWeather.observations.winddir -lt 247.5) {$arrow = $([char]0x2197)}
elseif ($CurrentWeather.observations.winddir -gt 247.5 -and $CurrentWeather.observations.winddir -lt 292.5) {$arrow = $([char]0x2192)}
elseif ($CurrentWeather.observations.winddir -gt 292.5 -and $CurrentWeather.observations.winddir -lt 337.5) {$arrow = $([char]0x2198)}
else {$arrow = $([char]0x2193)}
#
if ($CurrentWeather.observations.winddir -gt 11.25 -and $CurrentWeather.observations.winddir -lt 33.75) {$CardinalDir = "NNE"}
elseif ($CurrentWeather.observations.winddir -gt 33.75 -and $CurrentWeather.observations.winddir -lt 56.25) {$CardinalDir = "NE"}
elseif ($CurrentWeather.observations.winddir -gt 56.25 -and $CurrentWeather.observations.winddir -lt 78.75) {$CardinalDir = "ENE"}
elseif ($CurrentWeather.observations.winddir -gt 78.75 -and $CurrentWeather.observations.winddir -lt 101.25) {$CardinalDir = "E"}
elseif ($CurrentWeather.observations.winddir -gt 101.25 -and $CurrentWeather.observations.winddir -lt 123.75) {$CardinalDir = "ESE"}
elseif ($CurrentWeather.observations.winddir -gt 123.75 -and $CurrentWeather.observations.winddir -lt 146.25) {$CardinalDir = "SE"}
elseif ($CurrentWeather.observations.winddir -gt 146.25 -and $CurrentWeather.observations.winddir -lt 168.75) {$CardinalDir = "SSE"}
elseif ($CurrentWeather.observations.winddir -gt 168.75 -and $CurrentWeather.observations.winddir -lt 191.25) {$CardinalDir = "S"}
elseif ($CurrentWeather.observations.winddir -gt 191.25 -and $CurrentWeather.observations.winddir -lt 213.75) {$CardinalDir = "SSW"}
elseif ($CurrentWeather.observations.winddir -gt 213.75 -and $CurrentWeather.observations.winddir -lt 236.25) {$CardinalDir = "SW"}
elseif ($CurrentWeather.observations.winddir -gt 236.25 -and $CurrentWeather.observations.winddir -lt 258.75) {$CardinalDir = "WSW"}
elseif ($CurrentWeather.observations.winddir -gt 258.75 -and $CurrentWeather.observations.winddir -lt 281.25) {$CardinalDir = "W"}
elseif ($CurrentWeather.observations.winddir -gt 281.25 -and $CurrentWeather.observations.winddir -lt 303.75) {$CardinalDir = "WNW"}
elseif ($CurrentWeather.observations.winddir -gt 303.75 -and $CurrentWeather.observations.winddir -lt 326.25) {$CardinalDir = "NW"}
elseif ($CurrentWeather.observations.winddir -gt 326.25 -and $CurrentWeather.observations.winddir -lt 348.75) {$CardinalDir = "NNW"}
else {$CardinalDir = "N"}
#
$Time = get-date -format "MM/dd HH:mm:ss"
#
# //BLUEIRIS OVERLAY
# checks rainfall. Rain accumulation less than .05" is ignored. Finally, the string is combined to form the weather.txt file output.
if ($CurrentWeather.observations.imperial.precipTotal -ge 0.05) {$json = Write-Output "PWS:$($CurrentWeather.observations.stationID) `nCond:$($Condition) `nTemp: $($CurrentWeather.observations.imperial.temp)F `nWind Chill: $($CurrentWeather.observations.imperial.windChill)F `nHumidity: $($CurrentWeather.observations.humidity)% `nWind Speed: $($arrow)$($CurrentWeather.observations.imperial.windSpeed) mph $($CardinalDir) `nRainfall: $($CurrentWeather.observations.imperial.precipTotal)"" `nPressure: $($CurrentWeather.observations.imperial.pressure)"" `nUltraviolet (UV): $($CurrentWeather.observations.uv) `nLast Updated: $($Time)"}
#
else {$json = Write-Output "PWS:$($CurrentWeather.observations.stationID) `nCond:$($Condition) `nTemp: $($CurrentWeather.observations.imperial.temp)F `nWind Chill: $($CurrentWeather.observations.imperial.windChill)F `nHumidity: $($CurrentWeather.observations.humidity)% `nWind Speed: $($arrow)$($CurrentWeather.observations.imperial.windSpeed) mph $($CardinalDir) `nRainfall: $($CurrentWeather.observations.imperial.precipTotal)"" `nPressure: $($CurrentWeather.observations.imperial.pressure)"" `nUltraviolet (UV): $($CurrentWeather.observations.uv) `nLast Updated: $($Time)"}
$json | Out-File -FilePath "C:\BI\TXT\weather.txt" -Encoding UTF8
clv -Name Condition
#
# Delete the registry value
reg delete "HKCU\SOFTWARE\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3" /v 1A10 /f
exit